[![PyPI][pypi_badge]][pypi_project] ![PythonVersions][pyversions] ![LICENSE][license_badge] [![CI][actions_status]][ci_workflow]

[pypi_project]: https://pypi.org/project/aws-clipper/
[pypi_badge]: https://img.shields.io/badge/pypi-v0.1.1-orange
[license_badge]: https://img.shields.io/badge/license-MIT-green
[pyversions]: https://img.shields.io/badge/python-3.8%20%7C%203.9%20%7C%203.10%20%7C%203.11-blue
[actions_status]: https://github.com/kai2nenobu/aws-clipper/actions/workflows/ci.yml/badge.svg
[ci_workflow]: https://github.com/kai2nenobu/aws-clipper/actions/workflows/ci.yml

# aws-clipper

`aws-clipper` dumps AWS CLI config from a simple YAML file.

## License

This project is developed and distributed under MIT license. See [LICENCE](./LICENSE) for more details.
